==> indigitall_flutter_plugin-2.1.1.tar.gz: lib/push/models/Push.dart <==
import 'dart:convert';
import 'dart:io';

import 'PushAction.dart';
import 'PushButton.dart';

class Push {
  /// String field name id
  static const String _ID = "id";

  /// String field name app key
  static const String _APP_KEY = "appKey";

  /// String field name title
  static const String _TITLE = "title";

  /// String field name body
  static const String _BODY = "body";

  /// String field name icon
  static const String _ICON = "icon";

  /// String field name image
  static const String _IMAGE = "image";

  /// String field name gif
  static const String _GIF = "gif";

  /// String field name layout
  static const String _LAYOUT = "layout";

  /// String field name data
  static const String _DATA = "data";

  /// String field name silent
  static const String _SILENT = "silent";

  /// String field name secured data
  static const String _SECUREDDATA = "securedData";

  /// String field name is disponsable
  static const String _ISDISPOSABLE = "isDisposable";

  /// String field name sending id
  static const String _SENDING_ID = "sendingId";

  /// String field name campaign id
  static const String _CAMPAIGN_ID = "campaignId";

  /// String field name push id
  static const String _PUSH_ID = "pushId";

  /// String field name push action
  static const String _ACTION = PushAction.ACTION;

  /// String field name push button
  static const String _BUTTONS = PushButton.BUTTONS;

  /// id of push
  int? id;

  /// appkey of application
  String? appKey;

  /// title of push
  String? title;

  /// body of push
  String? body;

  /// icon
  String? icon;

  /// image if is show
  String? image;

  /// gif or thre images
  List<String>? gif;

  /// action of push
  PushAction? action;

  /// buttons of push if it was showed
  List<PushButton> buttons = [];

  /// layout type
  Layout? layout;

  /// data attach
  String? data;

  /// if push is silent or not
  bool silent = false;

  /// secured data if it was disponsable
  String? securedData;

  /// if push disponsable
  bool isDisposable = true;

  /// sending id
  String? sendingId;

  /// campaign id
  String? campaignId;

  /// push id to hybrid sdk
  int? pushId;

  /// Constructor of [Push]
  Push(Map map) {
    try {
      map.forEach((key, value) {
        switch (key) {
          case _ID:
            id = int.parse(value.toString());
            break;
          case _APP_KEY:
            appKey = value.toString();
            break;
          case _TITLE:
            title = value.toString();
            break;
          case _BODY:
            body = value.toString();
            break;
          case _ICON:
            icon = value.toString();
            break;
          case _IMAGE:
            image = value.toString();
            break;
          case _GIF:
            gif = json.decode(value.toString());
            break;
          case _LAYOUT:
            layout = parseLayout(value.toString());
            break;
          case _DATA:
            data = value.toString();
            break;
          case _SILENT:
            silent = value.toString() == "true";
            break;
          case _SECUREDDATA:
            securedData = value.toString();
            break;
          case _ISDISPOSABLE:
            isDisposable = value.toString() == "true";
            break;
          case _SENDING_ID:
            sendingId = value.toString();
            break;
          case _CAMPAIGN_ID:
            campaignId = value.toString();
            break;
          case _PUSH_ID:
            pushId = int.parse(value.toString());
            break;
          case _ACTION:
            if (Platform.isAndroid) {
              action = PushAction(json.decode(value.toString()));
            } else {
              action = PushAction(value);
            }
            break;
          case _BUTTONS:
            List<dynamic>? list = json.decode(value.toString());
            if (list != null) {
              for (var i = 0; i < list.length; i++) {
                buttons.add(PushButton(list[i]));
              }
            }
            break;
        }
      });
    } catch (ex) {
      print("push object error:" + ex.toString());
    }
  }

  /// Conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (id != null) map[_ID] = id;
    if (appKey != null) map[_APP_KEY] = appKey;
    if (title != null) map[_TITLE] = title;
    if (body != null) map[_BODY] = body;
    if (icon != null) map[_ICON] = icon;
    if (image != null) map[_IMAGE] = image;
    if (gif != null) map[_GIF] = gif.toString();
    if (action != null) map[_ACTION] = action;
    if (buttons.isNotEmpty) {
      PushButton? buttonMap;
      for (var i = 0; i < buttons.length; i++) {
        buttonMap = buttons[i];
      }
      map[_BUTTONS] = buttonMap;
    }
    if (layout != null) map[_LAYOUT] = layout.toString();
    if (data != null) map[_DATA] = data;
    map[_SILENT] = silent;
    if (securedData != null) map[_SECUREDDATA] = securedData;
    map[_ISDISPOSABLE] = isDisposable;
    if (sendingId != null) map[_SENDING_ID] = sendingId;
    if (pushId != null) map[_PUSH_ID] = pushId;
    return map;
  }
}

/// Enum with layout type
enum Layout { layout_native, custom, half_width, full_width }

/// get [Layout] name
String getLayoutName(Layout layout) {
  String value = "layout_native";
  switch (layout) {
    case Layout.custom:
      value = "custom";
      break;
    case Layout.half_width:
      value = "half_width";
      break;
    case Layout.full_width:
      value = "full_width";
      break;
    case Layout.layout_native:
      value = "layout_native";
      break;
  }
  return value;
}

Layout parseLayout(String str) {
  if (getLayoutName(Layout.layout_native) == str)
    return Layout.half_width;
  else if (getLayoutName(Layout.full_width) == str)
    return Layout.full_width;
  else if (getLayoutName(Layout.custom) == str)
    return Layout.custom;
  else
    return Layout.layout_native;
}

==> indigitall_flutter_plugin-2.1.3.tar.gz: lib/push/models/Push.dart <==
import 'dart:convert';
import 'dart:io';

import 'PushAction.dart';
import 'PushButton.dart';

class Push {
  /// String field name id
  static const String _ID = "id";

  /// String field name app key
  static const String _APP_KEY = "appKey";

  /// String field name title
  static const String _TITLE = "title";

  /// String field name body
  static const String _BODY = "body";

  /// String field name icon
  static const String _ICON = "icon";

  /// String field name image
  static const String _IMAGE = "image";

  /// String field name gif
  static const String _GIF = "gif";

  /// String field name layout
  static const String _LAYOUT = "layout";

  /// String field name data
  static const String _DATA = "data";

  /// String field name silent
  static const String _SILENT = "silent";

  /// String field name secured data
  static const String _SECUREDDATA = "securedData";

  /// String field name is disponsable
  static const String _ISDISPOSABLE = "isDisposable";

  /// String field name sending id
  static const String _SENDING_ID = "sendingId";

  /// String field name campaign id
  static const String _CAMPAIGN_ID = "campaignId";

  /// String field name push id
  static const String _PUSH_ID = "pushId";

  /// String field name push action
  static const String _ACTION = PushAction.ACTION;

  /// String field name push button
  static const String _BUTTONS = PushButton.BUTTONS;

  /// id of push
  int? id;

  /// appkey of application
  String? appKey;

  /// title of push
  String? title;

  /// body of push
  String? body;

  /// icon
  String? icon;

  /// image if is show
  String? image;

  /// gif or thre images
  List<String>? gif;

  /// action of push
  PushAction? action;

  /// buttons of push if it was showed
  List<PushButton> buttons = [];

  /// layout type
  Layout? layout;

  /// data attach
  String? data;

  /// if push is silent or not
  bool silent = false;

  /// secured data if it was disponsable
  String? securedData;

  /// if push disponsable
  bool isDisposable = true;

  /// sending id
  String? sendingId;

  /// campaign id
  String? campaignId;

  /// push id to hybrid sdk
  int? pushId;

  /// Constructor of [Push]
  Push(Map map) {
    try {
      map.forEach((key, value) {
        switch (key) {
          case _ID:
            id = int.parse(value.toString());
            break;
          case _APP_KEY:
            appKey = value.toString();
            break;
          case _TITLE:
            title = value.toString();
            break;
          case _BODY:
            body = value.toString();
            break;
          case _ICON:
            icon = value.toString();
            break;
          case _IMAGE:
            image = value.toString();
            break;
          case _GIF:
            gif = json.decode(value.toString());
            break;
          case _LAYOUT:
            layout = parseLayout(value.toString());
            break;
          case _DATA:
            data = value.toString();
            break;
          case _SILENT:
            silent = value.toString() == "true";
            break;
          case _SECUREDDATA:
            securedData = value.toString();
            break;
          case _ISDISPOSABLE:
            isDisposable = value.toString() == "true";
            break;
          case _SENDING_ID:
            sendingId = value.toString();
            break;
          case _CAMPAIGN_ID:
            campaignId = value.toString();
            break;
          case _PUSH_ID:
            pushId = int.parse(value.toString());
            break;
          case _ACTION:
            if (Platform.isAndroid) {
              if (value is Map<String, dynamic>) {
                action = PushAction(value);  
              } else if (value is String) {
                action = PushAction(json.decode(value));
              }              
            } else {
              action = PushAction(value);
            }
            break;
          case _BUTTONS:
            List<dynamic>? list = json.decode(value.toString());
            if (list != null) {
              for (var i = 0; i < list.length; i++) {
                buttons.add(PushButton(list[i]));
              }
            }
            break;
        }
      });
    } catch (ex) {
      print("push object error:" + ex.toString());
    }
  }

  /// Conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (id != null) map[_ID] = id;
    if (appKey != null) map[_APP_KEY] = appKey;
    if (title != null) map[_TITLE] = title;
    if (body != null) map[_BODY] = body;
    if (icon != null) map[_ICON] = icon;
    if (image != null) map[_IMAGE] = image;
    if (gif != null) map[_GIF] = gif.toString();
    if (action != null) map[_ACTION] = action?.toMap();
    if (buttons.isNotEmpty) {
      PushButton? buttonMap;
      for (var i = 0; i < buttons.length; i++) {
        buttonMap = buttons[i];
      }
      map[_BUTTONS] = buttonMap?.toMap();
    }
    if (layout != null) map[_LAYOUT] = layout.toString();
    if (data != null) map[_DATA] = data;
    map[_SILENT] = silent;
    if (securedData != null) map[_SECUREDDATA] = securedData;
    map[_ISDISPOSABLE] = isDisposable;
    if (sendingId != null) map[_SENDING_ID] = sendingId;
    if (pushId != null) map[_PUSH_ID] = pushId;
    return map;
  }
}

/// Enum with layout type
enum Layout { layout_native, custom, half_width, full_width }

/// get [Layout] name
String getLayoutName(Layout layout) {
  String value = "layout_native";
  switch (layout) {
    case Layout.custom:
      value = "custom";
      break;
    case Layout.half_width:
      value = "half_width";
      break;
    case Layout.full_width:
      value = "full_width";
      break;
    case Layout.layout_native:
      value = "layout_native";
      break;
  }
  return value;
}

Layout parseLayout(String str) {
  if (getLayoutName(Layout.layout_native) == str)
    return Layout.half_width;
  else if (getLayoutName(Layout.full_width) == str)
    return Layout.full_width;
  else if (getLayoutName(Layout.custom) == str)
    return Layout.custom;
  else
    return Layout.layout_native;
}
